@@ -270,8 +270,10 @@ static void _check_raid_seg(struct lv_segment *seg, int *error_count)
 	if (!seg->area_count)
 		raid_seg_error("zero area count");
 
-	if (!seg->areas)
+	if (!seg->areas) {
 		raid_seg_error("zero areas");
+		return;
+	}
 
 	if (seg->extents_copied > seg->len)
 		raid_seg_error_val("extents_copied too large", seg->extents_copied);
@@ -371,7 +373,7 @@ static void _check_lv_segment(struct logical_volume *lv, struct lv_segment *seg,
 			seg_error("sets cleaner_policy");
 	}
 
-	if (lv_is_cache(lv) && seg->pool_lv && lv_is_cache_vol(seg->pool_lv)) {
+	if (seg->pool_lv && lv_is_cache(lv) && lv_is_cache_vol(seg->pool_lv)) {
 		cache_setting_seg = seg;
 		no_metadata_format = 1;
 	}
@@ -495,6 +497,8 @@ static void _check_lv_segment(struct logical_volume *lv, struct lv_segment *seg,
 			seg_error("sets discards");
 		if (!dm_list_empty(&seg->thin_messages))
 			seg_error("sets thin_messages list");
+		if (seg->lv->status & LV_CROP_METADATA)
+			seg_error("sets CROP_METADATA flag");
 	}
 
 	if (seg_is_thin_volume(seg)) {
@@ -541,11 +545,61 @@ static void _check_lv_segment(struct logical_volume *lv, struct lv_segment *seg,
 			seg_error("is missing a VDO pool data LV");
 		} else if (!lv_is_vdo_pool_data(seg_lv(seg, 0)))
 			seg_error("is not VDO pool data LV");
+		if ((seg->vdo_params.minimum_io_size != (512 >> SECTOR_SHIFT)) &&
+		    (seg->vdo_params.minimum_io_size != (4096 >> SECTOR_SHIFT)))
+			seg_error("sets unsupported VDO minimum io size");
+		if ((seg->vdo_params.block_map_cache_size_mb < DM_VDO_BLOCK_MAP_CACHE_SIZE_MINIMUM_MB) ||
+		    (seg->vdo_params.block_map_cache_size_mb > DM_VDO_BLOCK_MAP_CACHE_SIZE_MAXIMUM_MB))
+			seg_error("sets unsupported VDO block map cache size");
+		if ((seg->vdo_params.block_map_era_length < DM_VDO_BLOCK_MAP_ERA_LENGTH_MINIMUM) ||
+		    (seg->vdo_params.block_map_era_length > DM_VDO_BLOCK_MAP_ERA_LENGTH_MAXIMUM))
+			seg_error("sets unsupported VDO block map era length");
+		if ((seg->vdo_params.index_memory_size_mb < DM_VDO_INDEX_MEMORY_SIZE_MINIMUM_MB) ||
+		    (seg->vdo_params.index_memory_size_mb > DM_VDO_INDEX_MEMORY_SIZE_MAXIMUM_MB))
+			seg_error("sets unsupported VDO index memory size");
+		if ((seg->vdo_params.slab_size_mb < DM_VDO_SLAB_SIZE_MINIMUM_MB) ||
+		    (seg->vdo_params.slab_size_mb > DM_VDO_SLAB_SIZE_MAXIMUM_MB))
+			seg_error("sets unsupported VDO slab size");
+		if ((seg->vdo_params.max_discard < DM_VDO_MAX_DISCARD_MINIMUM) ||
+		    (seg->vdo_params.max_discard > DM_VDO_MAX_DISCARD_MAXIMUM))
+			seg_error("sets unsupported VDO max discard");
+		if (seg->vdo_params.ack_threads > DM_VDO_ACK_THREADS_MAXIMUM)
+			seg_error("sets unsupported VDO ack threads");
+		if ((seg->vdo_params.bio_threads < DM_VDO_BIO_THREADS_MINIMUM) ||
+		    (seg->vdo_params.bio_threads > DM_VDO_BIO_THREADS_MAXIMUM))
+			seg_error("sets unsupported VDO bio threads");
+		if ((seg->vdo_params.bio_rotation < DM_VDO_BIO_ROTATION_MINIMUM) ||
+		    (seg->vdo_params.bio_rotation > DM_VDO_BIO_ROTATION_MAXIMUM))
+			seg_error("sets unsupported VDO bio rotation");
+		if ((seg->vdo_params.cpu_threads < DM_VDO_CPU_THREADS_MINIMUM) ||
+		    (seg->vdo_params.cpu_threads > DM_VDO_CPU_THREADS_MAXIMUM))
+			seg_error("sets unsupported VDO cpu threads");
+		if (seg->vdo_params.hash_zone_threads > DM_VDO_HASH_ZONE_THREADS_MAXIMUM)
+			seg_error("sets unsupported VDO hash zone threads");
+		if (seg->vdo_params.logical_threads > DM_VDO_LOGICAL_THREADS_MAXIMUM)
+			seg_error("sets unsupported VDO logical threads");
+		if (seg->vdo_params.physical_threads > DM_VDO_PHYSICAL_THREADS_MAXIMUM)
+			seg_error("sets unsupported VDO physical threads");
 	} else { /* !VDO pool */
 		if (seg->vdo_pool_header_size)
 			seg_error("sets vdo_pool_header_size");
 		if (seg->vdo_pool_virtual_extents)
 			seg_error("sets vdo_pool_virtual_extents");
+		if (seg->vdo_params.minimum_io_size |
+		    seg->vdo_params.block_map_cache_size_mb |
+		    seg->vdo_params.block_map_era_length |
+		    seg->vdo_params.check_point_frequency |
+		    seg->vdo_params.index_memory_size_mb |
+		    seg->vdo_params.slab_size_mb |
+		    seg->vdo_params.max_discard |
+		    seg->vdo_params.ack_threads |
+		    seg->vdo_params.bio_threads |
+		    seg->vdo_params.bio_rotation |
+		    seg->vdo_params.cpu_threads |
+		    seg->vdo_params.hash_zone_threads |
+		    seg->vdo_params.logical_threads |
+		    seg->vdo_params.physical_threads)
+			seg_error("sets vdo_params");
 	}
 
 	if (seg_is_vdo(seg)) {
