@@ -12,10 +12,10 @@
  * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-#include "lib.h"
-#include "properties.h"
-#include "activate.h"
-#include "metadata.h"
+#include "lib/misc/lib.h"
+#include "lib/report/properties.h"
+#include "lib/activate/activate.h"
+#include "lib/metadata/metadata.h"
 
 
 #define GET_VG_NUM_PROPERTY_FN(NAME, VALUE) \
@@ -91,6 +91,48 @@ static uint32_t _raidmaxrecoveryrate(const struct logical_volume *lv)
 	return first_seg(lv)->max_recovery_rate;
 }
 
+static const char *_raidintegritymode(const struct logical_volume *lv)
+{
+	struct integrity_settings *settings = NULL;
+
+	if (lv_raid_has_integrity((struct logical_volume *)lv))
+		lv_get_raid_integrity_settings((struct logical_volume *)lv, &settings);
+	else if (lv_is_integrity(lv))
+		settings = &first_seg(lv)->integrity_settings;
+
+	if (settings) {
+		switch (settings->mode[0]) {
+		case 'B': return "bitmap";
+		case 'J': return "journal";
+		}
+	}
+
+	return "unknown";
+}
+
+static uint32_t _raidintegrityblocksize(const struct logical_volume *lv)
+{
+	struct integrity_settings *settings = NULL;
+
+	if (lv_raid_has_integrity((struct logical_volume *)lv))
+		lv_get_raid_integrity_settings((struct logical_volume *)lv, &settings);
+	else if (lv_is_integrity(lv))
+		settings = &first_seg(lv)->integrity_settings;
+	else
+		return 0;
+
+	return (settings) ? settings->block_size : 0;
+}
+
+static uint64_t _integritymismatches(const struct logical_volume *lv)
+{
+	uint64_t cnt;
+
+	if (!lv_integrity_mismatches(lv->vg->cmd, lv, &cnt))
+		return 0;
+	return cnt;
+}
+
 static dm_percent_t _snap_percent(const struct logical_volume *lv)
 {
 	dm_percent_t percent;
@@ -199,6 +241,10 @@ GET_PV_NUM_PROPERTY_FN(pv_ba_start, SECTOR_SIZE * pv->ba_start)
 #define _pv_ba_start_set prop_not_implemented_set
 GET_PV_NUM_PROPERTY_FN(pv_ba_size, SECTOR_SIZE * pv->ba_size)
 #define _pv_ba_size_set prop_not_implemented_set
+GET_PV_STR_PROPERTY_FN(pv_device_id, pv->device_id)
+#define _pv_device_id_set prop_not_implemented_set
+GET_PV_STR_PROPERTY_FN(pv_device_id_type, pv->device_id_type)
+#define _pv_device_id_type_set prop_not_implemented_set
 
 #define _pv_allocatable_set prop_not_implemented_set
 #define _pv_allocatable_get prop_not_implemented_get
@@ -223,6 +269,8 @@ GET_PV_NUM_PROPERTY_FN(pv_ba_size, SECTOR_SIZE * pv->ba_size)
 #define _vg_extendable_get prop_not_implemented_get
 #define _vg_exported_set prop_not_implemented_set
 #define _vg_exported_get prop_not_implemented_get
+#define _vg_autoactivation_set prop_not_implemented_set
+#define _vg_autoactivation_get prop_not_implemented_get
 #define _vg_partial_set prop_not_implemented_set
 #define _vg_partial_get prop_not_implemented_get
 #define _vg_allocation_policy_set prop_not_implemented_set
@@ -277,6 +325,8 @@ GET_PV_NUM_PROPERTY_FN(pv_ba_size, SECTOR_SIZE * pv->ba_size)
 #define _lv_skip_activation_get prop_not_implemented_get
 #define _lv_check_needed_set prop_not_implemented_set
 #define _lv_check_needed_get prop_not_implemented_get
+#define _lv_autoactivation_set prop_not_implemented_set
+#define _lv_autoactivation_get prop_not_implemented_get
 #define _lv_historical_set prop_not_implemented_set
 #define _lv_historical_get prop_not_implemented_get
 
@@ -295,6 +345,64 @@ GET_PV_NUM_PROPERTY_FN(pv_ba_size, SECTOR_SIZE * pv->ba_size)
 #define _cache_write_misses_set prop_not_implemented_set
 #define _cache_write_misses_get prop_not_implemented_get
 
+#define _writecache_total_blocks_set prop_not_implemented_set
+#define _writecache_total_blocks_get prop_not_implemented_get
+#define _writecache_free_blocks_set prop_not_implemented_set
+#define _writecache_free_blocks_get prop_not_implemented_get
+#define _writecache_writeback_blocks_set prop_not_implemented_set
+#define _writecache_writeback_blocks_get prop_not_implemented_get
+#define _writecache_error_set prop_not_implemented_set
+#define _writecache_error_get prop_not_implemented_get
+
+#define _vdo_operating_mode_set prop_not_implemented_set
+#define _vdo_operating_mode_get prop_not_implemented_get
+#define _vdo_compression_state_set prop_not_implemented_set
+#define _vdo_compression_state_get prop_not_implemented_get
+#define _vdo_index_state_set prop_not_implemented_set
+#define _vdo_index_state_get prop_not_implemented_get
+#define _vdo_used_size_set prop_not_implemented_set
+#define _vdo_used_size_get prop_not_implemented_get
+#define _vdo_saving_percent_set prop_not_implemented_set
+#define _vdo_saving_percent_get prop_not_implemented_get
+#define _vdo_compression_set prop_not_implemented_set
+#define _vdo_compression_get prop_not_implemented_get
+#define _vdo_deduplication_set prop_not_implemented_set
+#define _vdo_deduplication_get prop_not_implemented_get
+#define _vdo_use_metadata_hints_set prop_not_implemented_set
+#define _vdo_use_metadata_hints_get prop_not_implemented_get
+#define _vdo_minimum_io_size_set prop_not_implemented_set
+#define _vdo_minimum_io_size_get prop_not_implemented_get
+#define _vdo_block_map_cache_size_set prop_not_implemented_set
+#define _vdo_block_map_cache_size_get prop_not_implemented_get
+#define _vdo_block_map_era_length_set prop_not_implemented_set
+#define _vdo_block_map_era_length_get prop_not_implemented_get
+#define _vdo_use_sparse_index_set prop_not_implemented_set
+#define _vdo_use_sparse_index_get prop_not_implemented_get
+#define _vdo_index_memory_size_set prop_not_implemented_set
+#define _vdo_index_memory_size_get prop_not_implemented_get
+#define _vdo_slab_size_set prop_not_implemented_set
+#define _vdo_slab_size_get prop_not_implemented_get
+#define _vdo_ack_threads_set prop_not_implemented_set
+#define _vdo_ack_threads_get prop_not_implemented_get
+#define _vdo_bio_threads_set prop_not_implemented_set
+#define _vdo_bio_threads_get prop_not_implemented_get
+#define _vdo_bio_rotation_set prop_not_implemented_set
+#define _vdo_bio_rotation_get prop_not_implemented_get
+#define _vdo_cpu_threads_set prop_not_implemented_set
+#define _vdo_cpu_threads_get prop_not_implemented_get
+#define _vdo_hash_zone_threads_set prop_not_implemented_set
+#define _vdo_hash_zone_threads_get prop_not_implemented_get
+#define _vdo_logical_threads_set prop_not_implemented_set
+#define _vdo_logical_threads_get prop_not_implemented_get
+#define _vdo_physical_threads_set prop_not_implemented_set
+#define _vdo_physical_threads_get prop_not_implemented_get
+#define _vdo_max_discard_set prop_not_implemented_set
+#define _vdo_max_discard_get prop_not_implemented_get
+#define _vdo_write_policy_set prop_not_implemented_set
+#define _vdo_write_policy_get prop_not_implemented_get
+#define _vdo_header_size_set prop_not_implemented_set
+#define _vdo_header_size_get prop_not_implemented_get
+
 /* LV */
 GET_LV_STR_PROPERTY_FN(lv_uuid, lv_uuid_dup(lv->vg->vgmem, lv))
 #define _lv_uuid_set prop_not_implemented_set
@@ -358,6 +466,12 @@ GET_LV_NUM_PROPERTY_FN(raid_max_recovery_rate, _raidmaxrecoveryrate(lv))
 #define _raid_max_recovery_rate_set prop_not_implemented_set
 GET_LV_STR_PROPERTY_FN(raid_sync_action, _raidsyncaction(lv))
 #define _raid_sync_action_set prop_not_implemented_set
+GET_LV_STR_PROPERTY_FN(raidintegritymode, _raidintegritymode(lv))
+#define _raidintegritymode_set prop_not_implemented_set
+GET_LV_NUM_PROPERTY_FN(raidintegrityblocksize, _raidintegrityblocksize(lv))
+#define _raidintegrityblocksize_set prop_not_implemented_set
+GET_LV_NUM_PROPERTY_FN(integritymismatches, _integritymismatches(lv))
+#define _integritymismatches_set prop_not_implemented_set
 GET_LV_STR_PROPERTY_FN(move_pv, lv_move_pv_dup(lv->vg->vgmem, lv))
 #define _move_pv_set prop_not_implemented_set
 GET_LV_STR_PROPERTY_FN(move_pv_uuid, lv_move_pv_uuid_dup(lv->vg->vgmem, lv))
