@@ -32,23 +32,23 @@ lvcreate -aey -L 16M -n $lv $vg
 check lv_field $vg/$lv segtype "linear"
 check lv_field $vg/$lv stripes 1
 check lv_field $vg/$lv data_stripes 1
-wipefs -a $DM_DEV_DIR/$vg/$lv
-mkfs -t ext4 $DM_DEV_DIR/$vg/$lv
-fsck -fn $DM_DEV_DIR/$vg/$lv
+wipefs -a "$DM_DEV_DIR/$vg/$lv"
+mkfs -t ext4 "$DM_DEV_DIR/$vg/$lv"
+fsck -fn "$DM_DEV_DIR/$vg/$lv"
 
 # Convert linear -> raid1 (takeover)
 lvconvert -y --type raid6 --stripes 3 --stripesize 64K --regionsize 128K $vg/$lv
-fsck -fn $DM_DEV_DIR/$vg/$lv
+fsck -fn "$DM_DEV_DIR/$vg/$lv"
 check lv_field $vg/$lv segtype "raid1"
 check lv_field $vg/$lv stripes 2
 check lv_field $vg/$lv data_stripes 2
 check lv_field $vg/$lv regionsize "128.00k"
 aux wait_for_sync $vg $lv
-fsck -fn $DM_DEV_DIR/$vg/$lv
+fsck -fn "$DM_DEV_DIR/$vg/$lv"
 
 # Convert raid1 -> raid5_ls (takeover)
 lvconvert -y --type raid6 --stripes 3 --stripesize 64K --regionsize 128K $vg/$lv
-fsck -fn $DM_DEV_DIR/$vg/$lv
+fsck -fn "$DM_DEV_DIR/$vg/$lv"
 check lv_field $vg/$lv segtype "raid5_ls"
 check lv_field $vg/$lv stripes 2
 check lv_field $vg/$lv data_stripes 1
@@ -57,7 +57,7 @@ check lv_field $vg/$lv regionsize "128.00k"
 
 # Convert raid5_ls adding stripes (reshape)
 lvconvert -y --type raid6 --stripes 3 --stripesize 64K --regionsize 128K $vg/$lv
-fsck -fn $DM_DEV_DIR/$vg/$lv
+fsck -fn "$DM_DEV_DIR/$vg/$lv"
 check lv_first_seg_field $vg/$lv segtype "raid5_ls"
 check lv_first_seg_field $vg/$lv stripes 4
 check lv_first_seg_field $vg/$lv data_stripes 3
@@ -65,11 +65,11 @@ check lv_first_seg_field $vg/$lv stripesize "64.00k"
 check lv_first_seg_field $vg/$lv regionsize "128.00k"
 check lv_first_seg_field $vg/$lv reshape_len_le 8
 aux wait_for_sync $vg $lv
-fsck -fn $DM_DEV_DIR/$vg/$lv
+fsck -fn "$DM_DEV_DIR/$vg/$lv"
 
 # Convert raid5_ls -> raid6_ls_6 (takeover)
 lvconvert -y --type raid6 --stripes 3 --stripesize 64K --regionsize 128K $vg/$lv
-fsck -fn $DM_DEV_DIR/$vg/$lv
+fsck -fn "$DM_DEV_DIR/$vg/$lv"
 check lv_first_seg_field $vg/$lv segtype "raid6_ls_6"
 check lv_first_seg_field $vg/$lv stripes 5
 check lv_first_seg_field $vg/$lv data_stripes 3
@@ -80,7 +80,7 @@ aux wait_for_sync $vg $lv
 
 # Convert raid6_ls_6 -> raid6(_zr) (reshape)
 lvconvert -y --type raid6 --stripes 3 --stripesize 64K --regionsize 128K $vg/$lv
-fsck -fn $DM_DEV_DIR/$vg/$lv
+fsck -fn "$DM_DEV_DIR/$vg/$lv"
 check lv_first_seg_field $vg/$lv segtype "raid6"
 check lv_first_seg_field $vg/$lv stripes 5
 check lv_first_seg_field $vg/$lv data_stripes 3
@@ -91,7 +91,7 @@ aux wait_for_sync $vg $lv
 
 # Remove reshape space
 lvconvert -y --type raid6 --stripes 3 --stripesize 64K --regionsize 128K $vg/$lv
-fsck -fn $DM_DEV_DIR/$vg/$lv
+fsck -fn "$DM_DEV_DIR/$vg/$lv"
 check lv_first_seg_field $vg/$lv segtype "raid6"
 check lv_first_seg_field $vg/$lv stripes 5
 check lv_first_seg_field $vg/$lv data_stripes 3
