@@ -19,7 +19,7 @@ SKIP_WITH_LVMPOLLD=1
 
 which md5sum || skip
 which mkfs.ext4 || skip
-aux have_raid 1 13 2 || skip
+aux have_raid 1 14 || skip
 
 mount_dir="mnt"
 
@@ -48,8 +48,8 @@ check lv_first_seg_field $vg/$lv1 segtype "raid5_ls"
 check lv_first_seg_field $vg/$lv1 stripesize "64.00k"
 check lv_first_seg_field $vg/$lv1 data_stripes 10
 check lv_first_seg_field $vg/$lv1 stripes 11
-wipefs -a /dev/$vg/$lv1
-mkfs -t ext4 /dev/$vg/$lv1
+wipefs -a "$DM_DEV_DIR/$vg/$lv1"
+mkfs -t ext4 "$DM_DEV_DIR/$vg/$lv1"
 
 mkdir -p "$mount_dir"
 mount "$DM_DEV_DIR/$vg/$lv1" "$mount_dir"
@@ -71,6 +71,10 @@ check lv_first_seg_field $vg/$lv1 data_stripes 15
 check lv_first_seg_field $vg/$lv1 stripes 16
 
 # Reload table during reshape to test for data corruption
+case "$(uname -r)" in
+  5.[89]*|5.1[012].*|3.10.0-862*|4.18.0-*.el8*)
+	should not echo "Skipping table reload test on on unfixed kernel!!!" ;;
+  *)
 for i in {0..5}
 do
 	dmsetup table $vg-$lv1|dmsetup load $vg-$lv1
@@ -79,6 +83,8 @@ do
 	sleep 0.3
 done
 
+esac
+
 aux delay_dev "$dev2" 0
 
 kill -9 %% || true
@@ -86,7 +92,7 @@ wait
 
 checksum_ "$mount_dir/random" >MD5_new
 
-umount $mount_dir
+umount "$mount_dir"
 
 fsck -fn "$DM_DEV_DIR/$vg/$lv1"
 
