@@ -11,16 +11,14 @@
 
 # Basic usage of zero target
 
-SKIP_WITH_LVMLOCKD=1
+
 SKIP_WITH_LVMPOLLD=1
 
 . lib/inittest
 
 which md5sum || skip
 
-aux prepare_pvs 1
-
-vgcreate -s 256k $vg $(cat DEVICES)
+aux prepare_vg 1
 
 lvcreate --type zero -L1 -n $lv1 $vg
 lvextend -L+1 $vg/$lv1
@@ -34,4 +32,15 @@ test "$sum1" = "$sum2"
 check lv_field $vg/$lv1 lv_modules "zero"
 check lv_field $vg/$lv1 segtype "zero"
 check lv_field $vg/$lv1 seg_count "1"
-check lv_field $vg/$lv1 seg_size_pe "8"   # 8 * 256
+check lv_field $vg/$lv1 seg_size_pe "4"   # 4 * 512
+
+lvextend -L+1 --type error $vg/$lv1
+lvextend -L+1 --type linear $vg/$lv1
+lvextend -L+1 --type striped $vg/$lv1
+lvextend -L+1 --type zero $vg/$lv1
+
+lvs -o+segtype,seg_size $vg
+check lv_field $vg/$lv1 seg_count "4"
+check lv_field $vg/$lv1 size "6.00m"
+
+vgremove -ff $vg
